> ## Documentation Index
> Fetch the complete documentation index at: https://docs.suprsend.com/llms.txt
> Use this file to discover all available pages before exploring further.

# Pull workflows with the SuprSend CLI

> Use the suprsend workflow pull command to download SuprSend workflows from a workspace to your local directory for editing and version control in Git.

Download workflow definitions from a workspace to local JSON files. Saves one JSON file per workflow (named by slug) to the output directory. Use `--slug` to pull a single workflow, or omit to pull all. <br /><br />
By default, pulled workflows are stored in the `suprsend/workflow/` directory, but you can change the destination using the -d flag.

## Syntax

```bash theme={"system"}
suprsend workflow pull [flags]
```

## Flags

| Flag | Description | Default |
| - | - | - |
| `-h, --help` | Show help for the command | – |
| `-g, --slug string` | Workflow slug to pull (omit to pull all) | – |
| `-d, --dir string` | Directory to save workflow files to | `./suprsend/workflow` |
| `-f, --force` | Skip directory confirmation prompt, use default path | – |
| `-m, --mode string` | Version mode: draft or live | `live` |

## Example

```bash theme={"system"}
# Pull all live workflows to current directory
suprsend workflow pull

# Pull workflows into custom directory path
suprsend workflow pull --dir dev-environment/workflows

# Pull draft workflows from production
suprsend workflow pull --mode draft --workspace production

# Pull individual workflow by passing it's slug
suprsend workflow pull --slug welcome-email
```


This documentation is built and hosted on [Mintlify](https://mintlify.com), a developer documentation platform.